import setuptools as set
from setuptools import find_packages

set.setup(
    name = "testfoRnExuDSA",
    version = "1.0.0",
    author = "Saad-py",
    author_email = "saadyarkhan11@gmail.com",
    description="Neux, a package intended to make all of the python users life easier ",
    long_description="Howdie Programmers,\nNeux is the library to help you make your python life easier.\n\nNeed Help?\n\nIf you are an experienced programmer You guys know you can use help() function in python\nIf you are a beginner be sure to keep checking the Github repo for Neux and I may upload YouTube videos explaining how Neux works\nThe docs will be released after the third major update because all the important things will be added by then.\n\n\nIssues: \nWant to talk create an issue on github or send an email to the given email located somewhere in the repo.\nCan't Find Email, Here it is: saadyarkhan11@gmail.com\nI am on Hangouts, but not Discord.\nThanks for Downloading",
    packages=find_packages(),
)

